@@ -1,7 +1,6 @@
 from webthing import (SingleThing, Property, Thing, Value, WebThingServer)
 from RPLCD.i2c import CharLCD, BaseCharLCD
 from pi_display_webthing.display import Display
-from pi_display_webthing.lcd import Lcd
 import tornado.ioloop
 import logging
 
@@ -10,7 +9,7 @@ class DisplayWebThing(Thing):
     # regarding capabilities refer https://iot.mozilla.org/schemas
     # there is also another schema registry http://iotschema.org/docs/full.html not used by webthing
 
-    def __init__(self, name: str, description: str, lcd: Lcd):
+    def __init__(self, name: str, description: str, lcd: BaseCharLCD):
         Thing.__init__(
             self,
             'urn:dev:ops:lcddisplay-1',
@@ -113,11 +112,11 @@ class DisplayWebThing(Thing):
 
     def __update_text_props(self):
         self.display_text.notify_of_external_update(self.display.text)
-        self.upper_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_UPPER).display_text)
+        self.upper_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_UPPER).text)
         self.upper_layer_text_ttl.notify_of_external_update(self.display.panel(Display.LAYER_UPPER).ttl)
-        self.middle_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_MIDDLE).display_text)
+        self.middle_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_MIDDLE).text)
         self.middle_layer_text_ttl.notify_of_external_update(self.display.panel(Display.LAYER_MIDDLE).ttl)
-        self.lower_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_LOWER).display_text)
+        self.lower_layer_text.notify_of_external_update(self.display.panel(Display.LAYER_LOWER).text)
         self.lower_layer_text_ttl.notify_of_external_update(self.display.panel(Display.LAYER_LOWER).ttl)
 
 
